@@ -275,9 +275,9 @@ class DataSetUploadHandler(IPythonHandler):
             # ...or return a success message
             self.write({
                 'status': 200,
-                'statusText': 'Jupyter Notebook was successfully uploaded to: {} with permId: {}'.format(conn.name, dataset.permId)
+                'statusText': 'DataSet successfully registered: {} with permId: {}'.format(conn.name, dataset.permId)
             })
-        print('Jupyter Notebook was successfully uploaded to: {} with permId: {}'.format(conn.name, dataset.permId))
+        print('DataSet successfully registered: {} with permId: {}'.format(conn.name, dataset.permId))
 
     def post(self, **params):
         """Handle a request to /openbis/dataset/connection_name/permId
